scipy.sparse.csr_matrix
=======================

.. currentmodule:: scipy.sparse

.. autoclass:: csr_matrix

   

   .. HACK
      .. autosummary::
         :toctree:
      
         csr_matrix.__init__
         csr_matrix.asformat
         csr_matrix.asfptype
         csr_matrix.astype
         csr_matrix.check_format
         csr_matrix.conj
         csr_matrix.conjugate
         csr_matrix.copy
         csr_matrix.diagonal
         csr_matrix.dot
         csr_matrix.eliminate_zeros
         csr_matrix.getH
         csr_matrix.get_shape
         csr_matrix.getcol
         csr_matrix.getformat
         csr_matrix.getmaxprint
         csr_matrix.getnnz
         csr_matrix.getrow
         csr_matrix.mean
         csr_matrix.multiply
         csr_matrix.nonzero
         csr_matrix.prune
         csr_matrix.reshape
         csr_matrix.set_shape
         csr_matrix.setdiag
         csr_matrix.sort_indices
         csr_matrix.sorted_indices
         csr_matrix.sum
         csr_matrix.sum_duplicates
         csr_matrix.toarray
         csr_matrix.tobsr
         csr_matrix.tocoo
         csr_matrix.tocsc
         csr_matrix.tocsr
         csr_matrix.todense
         csr_matrix.todia
         csr_matrix.todok
         csr_matrix.tolil
         csr_matrix.transpose



   

   .. HACK
      .. autosummary::
         :toctree:
      
         csr_matrix.dtype
         csr_matrix.has_sorted_indices
         csr_matrix.nnz
         csr_matrix.shape

